import click
import json
import requests

from decouple import config
from .helper import OTPCredentials, load_dump_pretty


@click.group()
def host():
    pass


@host.command("add")
@click.option("--name", envvar="OTP_NAME", required=True)
@click.option("--realm", envvar="OTP_REALM", required=True)
@click.option("--seed", envvar="OTP_SEED", required=True)
@click.option("--specs", required=True)
@click.option("--hostname", required=True)
def add_host(name, realm, seed, specs, hostname):
    with open(specs, "r") as specs_f:
        specs = json.loads(specs_f.read())
        data = {
            **OTPCredentials(name, realm, seed).get_json(),
            "specs": specs,
            "hostname": hostname,
        }
        r = requests.post(f"{config('UCLOUD_API_SERVER')}/host/create", json=data)
        print(load_dump_pretty(r.content))


@host.command("list")
def list_host():
    r = requests.get(f"{config('UCLOUD_API_SERVER')}/host/list")
    print(load_dump_pretty(r.content))